==> eslint-plugin-angular-0.3.0.tgz: package/test/ng_di.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var eslint = require('../node_modules/eslint/lib/eslint'),
    ESLintTester = require('eslint-tester');

var angularNamedObjectList = ['value', 'factory', 'service', 'provider', 'controller', 'filter', 'directive'];
var angularObjectList = ['run', 'config'];


var valid = [], invalid = [];

angularObjectList.forEach(function(object){
  valid.push({
      code: 'angular.' + object + '(function(){});',
      args: [1, 'function']
  }, {
      code: 'angular.' + object + '([function(){}]);',
      args: [1, 'array']
  }, {
      code: 'angular.' + object + '(["Service1", function(Service1){}]);',
      args: [1, 'array']
  }, {
      code: 'angular.' + object + '(myFunction);function MyFunction(){}',
      args: [1, 'function']
  });

  invalid.push({
      code: 'angular.' + object + '(function(){});',
      args: [1, 'array'],
      errors: [{ message: 'You should use the array syntax for DI'}]
  }, {
      code: 'angular.' + object + '([function(){}]);',
      args: [1, 'function'],
      errors: [{ message: 'You should use the function syntax for DI'}]
  }, {
      code: 'angular.' + object + '(["Service1", function(){}]);',
      args: [1, 'array'],
      errors: [{ message: 'The signature of the method is incorrect'}]
  }, {
      code: 'angular.' + object + '([function(Service1){}]);',
      args: [1, 'array'],
      errors: [{ message: 'The signature of the method is incorrect'}]
  });
});

angularNamedObjectList.forEach(function(object){
    valid.push({
        code: 'angular.' + object + '("name", function(){});',
        args: [1, 'function']
    }, {
        code: 'angular.' + object + '("name", [function(){}]);',
        args: [1, 'array']
    }, {
        code: 'angular.' + object + '("name", ["Service1", function(Service1){}]);',
        args: [1, 'array']
    }, {
        code: 'angular.' + object + '("name", myFunction);function MyFunction(){}',
        args: [1, 'function']
    });

    invalid.push({
        code: 'angular.' + object + '("name", function(){});',
        args: [1, 'array'],
        errors: [{ message: 'You should use the array syntax for DI'}]
    }, {
        code: 'angular.' + object + '("name", [function(){}]);',
        args: [1, 'function'],
        errors: [{ message: 'You should use the function syntax for DI'}]
    }, {
        code: 'angular.' + object + '("name", ["Service1", function(){}]);',
        args: [1, 'array'],
        errors: [{ message: 'The signature of the method is incorrect'}]
    }, {
        code: 'angular.' + object + '("name", [function(Service1){}]);',
        args: [1, 'array'],
        errors: [{ message: 'The signature of the method is incorrect'}]
    });
});


valid.push({
    code: 'vm.navRoutes = states.filter(x).sort(y);',
    args: [1, 'function']
}, {
    code: 'vm.navRoutes = states.filter(x).sort(y);',
    args: [1, 'array']
}, {
    code: 'mocha.run();',
    args: [1, 'array']
})
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------



var eslintTester = new ESLintTester(eslint);
eslintTester.addRuleTest('rules/ng_di', {
    valid: valid,
    invalid: invalid
});

==> eslint-plugin-angular-0.5.0.tgz: package/test/ng_di.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require('../rules/ng_di'),
    RuleTester = require("eslint").RuleTester;


var angularNamedObjectList = ['value', 'factory', 'service', 'provider', 'controller', 'filter', 'directive'];
var angularObjectList = ['run', 'config'];


var valid = [], invalid = [];

angularObjectList.forEach(function(object){
  valid.push({
      code: 'angular.' + object + '(function(){});',
      options: ['function']
  }, {
      code: 'angular.' + object + '([function(){}]);',
      options: ['array']
  }, {
      code: 'angular.' + object + '(["Service1", function(Service1){}]);',
      options: ['array']
  }, {
      code: 'angular.' + object + '(myFunction);function MyFunction(){}',
      options: ['function']
  });

  invalid.push({
      code: 'angular.' + object + '(function(){});',
      options: ['array'],
      errors: [{ message: 'You should use the array syntax for DI'}]
  }, {
      code: 'angular.' + object + '([function(){}]);',
      options: ['function'],
      errors: [{ message: 'You should use the function syntax for DI'}]
  }, {
      code: 'angular.' + object + '(["Service1", function(){}]);',
      options: ['array'],
      errors: [{ message: 'The signature of the method is incorrect'}]
  }, {
      code: 'angular.' + object + '([function(Service1){}]);',
      options: ['array'],
      errors: [{ message: 'The signature of the method is incorrect'}]
  });
});

angularNamedObjectList.forEach(function(object){
    valid.push({
        code: 'angular.' + object + '("name", function(){});',
        options: ['function']
    }, {
        code: 'angular.' + object + '("name", [function(){}]);',
        options: ['array']
    }, {
        code: 'angular.' + object + '("name", ["Service1", function(Service1){}]);',
        options: ['array']
    }, {
        code: 'angular.' + object + '("name", myFunction);function MyFunction(){}',
        options: ['function']
    });

    invalid.push({
        code: 'angular.' + object + '("name", function(){});',
        options: ['array'],
        errors: [{ message: 'You should use the array syntax for DI'}]
    }, {
        code: 'angular.' + object + '("name", [function(){}]);',
        options: ['function'],
        errors: [{ message: 'You should use the function syntax for DI'}]
    }, {
        code: 'angular.' + object + '("name", ["Service1", function(){}]);',
        options: ['array'],
        errors: [{ message: 'The signature of the method is incorrect'}]
    }, {
        code: 'angular.' + object + '("name", [function(Service1){}]);',
        options: ['array'],
        errors: [{ message: 'The signature of the method is incorrect'}]
    });
});


valid.push({
    code: 'vm.navRoutes = states.filter(x).sort(y);',
    options: ['function']
}, {
    code: 'vm.navRoutes = states.filter(x).sort(y);',
    options: ['array']
}, {
    code: 'mocha.run();',
    options: ['array']
})
//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new RuleTester();
eslintTester.run('ng_di', rule, {
    valid: valid,
    invalid: invalid
});
